@@ -37,9 +37,26 @@ tf_v2 <- function() {
 .globals <- new.env(parent = emptyenv())
 .globals$tensorboard <- NULL
 
+#' @export
+#' @rdname install_tensorflow
+py_require_tensorflow <- function(use_gpu = NA) {
+  # register requirements with py_require()
+  reqs <- get_py_requirements(use_gpu)
+  reticulate::py_require(reqs$packages, reqs$python_version)
+}
 
 .onLoad <- function(libname, pkgname) {
 
+  # if (is.na(Sys.getenv("TF_CPP_MIN_LOG_LEVEL", NA))) {
+  #   ## Doesn't seem to make a difference
+  #   Sys.setenv("TF_CPP_MIN_LOG_LEVEL" = "3")
+  # }
+  # 0 = all messages are logged (default behavior)
+  # 1 = INFO messages are not printed
+  # 2 = INFO and WARNING messages are not printed
+  # 3 = INFO, WARNING, and ERROR messages are not printed
+
+
   # if TENSORFLOW_PYTHON is defined then forward it to RETICULATE_PYTHON
   tensorflow_python <- Sys.getenv("TENSORFLOW_PYTHON", unset = NA)
   if (!is.na(tensorflow_python))
@@ -51,6 +68,10 @@ tf_v2 <- function() {
   if (!is.null(cpp_log_opt))
     Sys.setenv(TF_CPP_MIN_LOG_LEVEL = max(min(cpp_log_opt, 3), 0))
 
+  if (tolower(Sys.getenv("PY_REQUIRE_TENSORFLOW")) %in% c("1", "true", "yes")) {
+    py_require_tensorflow()
+  }
+
   # delay load tensorflow
   tryCatch({
 
@@ -60,7 +81,8 @@ tf_v2 <- function() {
 
     environment = c(
       "r-tensorflow",
-      if(getNamespaceVersion("reticulate") >= "1.36.0") "r-keras"
+      if (as.package_version(getNamespaceVersion("reticulate")) >= "1.36.0")
+         "r-keras"
     ),
 
     # before_load = function() {
@@ -210,7 +232,7 @@ print.tensorflow_config <- function(x, ...) {
   if (x$available) {
     aliased <- function(path) sub(Sys.getenv("HOME"), "~", path)
     cat("TensorFlow v", x$version_str, " (", aliased(x$location), ")\n", sep = "")
-    cat("Python v", x$python_version, " (", aliased(x$python), ")\n", sep = "")
+    cat("Python v", as.character(x$python_version), " (", aliased(x$python), ")\n", sep = "")
   } else {
     cat(x$error_message, "\n")
   }
@@ -273,5 +295,8 @@ tf_config_error_message <- function() {
 
   message <- paste0(message,
                     "\nYou can install TensorFlow using the install_tensorflow() function.\n")
+  base::message(
+    'Hint: To use tensorflow with `py_require()`, call `py_require("tensorflow")` at the start of the R session'
+  )
   message
 }
